@@ -11,6 +11,11 @@ if (@ARGV != 4) {
 
 my $doc = Document::OOXML->read_document($ARGV[0]);
 
+# Ensure all "matching" text is merged into single runs, so find/replace
+# can actually find all the words.
+$doc->merge_runs();
+
+# Do the actual replacing
 $doc->replace_text($ARGV[2], $ARGV[3]);
 
 $doc->save_to_file($ARGV[1]);
\ No newline at end of file
