@@ -15,6 +15,6 @@ my $doc = Document::OOXML->read_document($ARGV[0]);
 # can actually find all the words.
 $doc->merge_runs();
 
-my $words = $doc->style_text(qr/\b$ARGV[2]\b/, bold => 1, italic => 1, color => '00FFFF');
+my $words = $doc->style_text(qr/\Q$ARGV[2]\E/, bold => 1, italic => 1, color => '00FFFF');
 
 $doc->save_to_file($ARGV[1]);
